==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementLongTermSecurityCredential.md <==
# AwsIdentityAccessManagementLongTermSecurityCredential


```text
aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementLongTermSecurityCredential
```

```text
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementLongTermSecurityCredential')
```



| Illustration | AwsIdentityAccessManagementLongTermSecurityCredential | AwsIdentityAccessManagementLongTermSecurityCredentialCard | AwsIdentityAccessManagementLongTermSecurityCredentialGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementLongTermSecurityCredential.png) | ![illustration for AwsIdentityAccessManagementLongTermSecurityCredential](../../../aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementLongTermSecurityCredential.Local.png) | ![illustration for AwsIdentityAccessManagementLongTermSecurityCredentialCard](../../../aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementLongTermSecurityCredentialCard.Local.png) | ![illustration for AwsIdentityAccessManagementLongTermSecurityCredentialGroup](../../../aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementLongTermSecurityCredentialGroup.Local.png) |




## AwsIdentityAccessManagementLongTermSecurityCredential

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementLongTermSecurityCredential
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementLongTermSecurityCredential')

' renders the element
AwsIdentityAccessManagementLongTermSecurityCredential('AwsIdentityAccessManagementLongTermSecurityCredential', 'Aws Identity Access Management Long Term Security Credential', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementLongTermSecurityCredential
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementLongTermSecurityCredential')

' renders the element
AwsIdentityAccessManagementLongTermSecurityCredential('AwsIdentityAccessManagementLongTermSecurityCredential', 'Aws Identity Access Management Long Term Security Credential', 'an optional tech label')
@enduml
```

## AwsIdentityAccessManagementLongTermSecurityCredentialCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementLongTermSecurityCredentialCard
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementLongTermSecurityCredential')

' renders the element
AwsIdentityAccessManagementLongTermSecurityCredentialCard('AwsIdentityAccessManagementLongTermSecurityCredentialCard', 'Aws Identity Access Management Long Term Security Credential Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementLongTermSecurityCredentialCard
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementLongTermSecurityCredential')

' renders the element
AwsIdentityAccessManagementLongTermSecurityCredentialCard('AwsIdentityAccessManagementLongTermSecurityCredentialCard', 'Aws Identity Access Management Long Term Security Credential Card', 'an optional description')
@enduml
```

## AwsIdentityAccessManagementLongTermSecurityCredentialGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementLongTermSecurityCredentialGroup
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementLongTermSecurityCredential')

' renders the element
AwsIdentityAccessManagementLongTermSecurityCredentialGroup('AwsIdentityAccessManagementLongTermSecurityCredentialGroup', 'Aws Identity Access Management Long Term Security Credential Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementLongTermSecurityCredentialGroup
include('aws-q3-2021/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementLongTermSecurityCredential')

' renders the element
AwsIdentityAccessManagementLongTermSecurityCredentialGroup('AwsIdentityAccessManagementLongTermSecurityCredentialGroup', 'Aws Identity Access Management Long Term Security Credential Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-7.1.0.tgz: package/distribution/aws-q1-2022/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementLongTermSecurityCredential.md <==
# AwsIdentityAccessManagementLongTermSecurityCredential


```text
aws-q1-2022/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementLongTermSecurityCredential
```

```text
include('aws-q1-2022/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementLongTermSecurityCredential')
```



| Illustration | AwsIdentityAccessManagementLongTermSecurityCredential | AwsIdentityAccessManagementLongTermSecurityCredentialCard | AwsIdentityAccessManagementLongTermSecurityCredentialGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q1-2022/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementLongTermSecurityCredential.png) | ![illustration for AwsIdentityAccessManagementLongTermSecurityCredential](../../../aws-q1-2022/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementLongTermSecurityCredential.Local.png) | ![illustration for AwsIdentityAccessManagementLongTermSecurityCredentialCard](../../../aws-q1-2022/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementLongTermSecurityCredentialCard.Local.png) | ![illustration for AwsIdentityAccessManagementLongTermSecurityCredentialGroup](../../../aws-q1-2022/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementLongTermSecurityCredentialGroup.Local.png) |




## AwsIdentityAccessManagementLongTermSecurityCredential

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementLongTermSecurityCredential
include('aws-q1-2022/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementLongTermSecurityCredential')

' renders the element
AwsIdentityAccessManagementLongTermSecurityCredential('AwsIdentityAccessManagementLongTermSecurityCredential', 'Aws Identity Access Management Long Term Security Credential', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementLongTermSecurityCredential
include('aws-q1-2022/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementLongTermSecurityCredential')

' renders the element
AwsIdentityAccessManagementLongTermSecurityCredential('AwsIdentityAccessManagementLongTermSecurityCredential', 'Aws Identity Access Management Long Term Security Credential', 'an optional tech label')
@enduml
```

## AwsIdentityAccessManagementLongTermSecurityCredentialCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementLongTermSecurityCredentialCard
include('aws-q1-2022/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementLongTermSecurityCredential')

' renders the element
AwsIdentityAccessManagementLongTermSecurityCredentialCard('AwsIdentityAccessManagementLongTermSecurityCredentialCard', 'Aws Identity Access Management Long Term Security Credential Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementLongTermSecurityCredentialCard
include('aws-q1-2022/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementLongTermSecurityCredential')

' renders the element
AwsIdentityAccessManagementLongTermSecurityCredentialCard('AwsIdentityAccessManagementLongTermSecurityCredentialCard', 'Aws Identity Access Management Long Term Security Credential Card', 'an optional description')
@enduml
```

## AwsIdentityAccessManagementLongTermSecurityCredentialGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementLongTermSecurityCredentialGroup
include('aws-q1-2022/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementLongTermSecurityCredential')

' renders the element
AwsIdentityAccessManagementLongTermSecurityCredentialGroup('AwsIdentityAccessManagementLongTermSecurityCredentialGroup', 'Aws Identity Access Management Long Term Security Credential Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementLongTermSecurityCredentialGroup
include('aws-q1-2022/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementLongTermSecurityCredential')

' renders the element
AwsIdentityAccessManagementLongTermSecurityCredentialGroup('AwsIdentityAccessManagementLongTermSecurityCredentialGroup', 'Aws Identity Access Management Long Term Security Credential Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
